# Write your code here :-)
# Full Final Project Code
import board, time, digitalio, pwmio
from hx711.hx711_gpio import HX711_GPIO
from digitalio import DigitalInOut
from analogio import AnalogIn
from lcd.lcd import LCD
from lcd.i2c_pcf8574_interface import I2CPCF8574Interface
from lcd.lcd import CursorMode
from adafruit_debouncer import Button
from adafruit_motor import servo
from adafruit_onewire.bus import OneWireBus
import adafruit_ds18x20

# Dial Selection Set Up
potentiometer = AnalogIn(board.GP28)

# Set up temp probe


## Set up kettle servo
pwm = pwmio.PWMOut(board.GP2, frequency=50)
servo_1 = servo.Servo(pwm, min_pulse = 600, max_pulse = 2250)
servo_1.angle = 80

button_input = digitalio.DigitalInOut(board.GP11) # Wired to GP15
button_input.switch_to_input(digitalio.Pull.UP) # Note: Pull.UP for external buttons
button = Button(button_input)

## Set up display
cols = 16
rows = 2
sda,scl = board.GP4, board.GP5
i2c = board.STEMMA_I2C()
i2c_address = 0x3f
interface = I2CPCF8574Interface(i2c, i2c_address)
lcd = LCD(interface, num_rows=rows, num_cols=cols)
lcd.set_cursor_mode(CursorMode.HIDE)

## Scale Set Up
gpio_data = DigitalInOut(board.GP6)
gpio_clk = DigitalInOut(board.GP7)
hx = HX711_GPIO(gpio_data, gpio_clk, scalar = 459, tare=True)

## Motor Set Up
## Grinder
in1 = digitalio.DigitalInOut(board.GP19)
in2 = digitalio.DigitalInOut(board.GP18)
in3 = digitalio.DigitalInOut(board.GP17)
in4 = digitalio.DigitalInOut(board.GP16)

in1.direction = digitalio.Direction.OUTPUT
in2.direction = digitalio.Direction.OUTPUT
in3.direction = digitalio.Direction.OUTPUT
in4.direction = digitalio.Direction.OUTPUT

# Pumps
in5 = digitalio.DigitalInOut(board.GP12)
in6 = digitalio.DigitalInOut(board.GP13)
in7 = digitalio.DigitalInOut(board.GP14)
in8 = digitalio.DigitalInOut(board.GP15)

in5.direction = digitalio.Direction.OUTPUT
in6.direction = digitalio.Direction.OUTPUT
in7.direction = digitalio.Direction.OUTPUT
in8.direction = digitalio.Direction.OUTPUT

lcd.print("Welcome!")
lcd.set_cursor_pos(1,0)
lcd.print("Press to start")
time.sleep(1)
button_count = 0

# Set Up Temp Probe
ow_bus = OneWireBus(board.GP0)
devices = ow_bus.scan()
temp_prob = adafruit_ds18x20.DS18X20(ow_bus, devices[0])

while True:
    button.update()
    reading = round(hx.read(5),1)

# Selecting the dose
    if button.pressed and button_count == 0:
        print("pressed")
        lcd.clear()
        lcd.set_cursor_pos(0,0)
        lcd.print("How Much Coffee?")
        if temp_prob.temperature < 97:
            servo_1.angle = 0
        else:
            servo_1.angle = 80
        while button_count == 0:
            potent_val = potentiometer.value
            water_dose = int(round(((potent_val/65535)*10),0)*10+200)
            coffee_dose = (water_dose/16.7)
            button.update()
            lcd.set_cursor_pos(1,0)
            lcd.print(str(water_dose) + " g")
            if button.pressed:
                button_count+=1
            time.sleep(.01)

# Grinding Coffee and dispensing water

    if button.pressed and button_count == 1:
        lcd.clear()
        selected_dose_water = water_dose
        selected_dose_coffee = coffee_dose
        lcd.set_cursor_pos(0,0)
        lcd.print("Dispensing " + str(selected_dose_water) + " g")
        if temp_prob.temperature < 95:
            servo_1.angle = 0
        else:
            servo_1.angle = 90

# Grinding the Coffee
        while reading < selected_dose_coffee:
            reading = round(hx.read(10),1)
            print(reading)
            in1.value = True
            in2.value = True
            in3.value = False
            in4.value = True
            lcd.set_cursor_pos(1,0)
            lcd.print(str(reading)+ " g Coffee")
        in1.value = False
        in2.value = False
        in3.value = False
        in4.value = False

        hx.tare()
        reading = round(hx.read(5),1)
        print(reading)
        temp = temp_prob.temperature

# Checking water temp
        lcd.clear()
        lcd.set_cursor_pos(0,0)
        lcd.print("Heating  Water")

        while temp < 95:
            temp = round(temp_prob.temperature,1)
            lcd.set_cursor_pos(1,0)
            lcd.print(temp + " C")
            pass
        servo_1.angle = 0

# Dispensing Water
        lcd.clear()
        lcd.set_cursor_pos(0,0)
        lcd.print("Dispensing " + str(selected_dose_water) + " g")

        while reading < selected_dose_coffee*3:
            temp = temp_prob.temperature
            if temp < 95:
                servo_1.angle = 0
            else:
                servo_1.angle = 90
            reading = round(hx.read(5),1)
            in5.value = True
            in6.value = False
            in7.value = True
            in8.value = False
            lcd.set_cursor_pos(1,0)
            lcd.print(str(reading)+ " g Water")
        in5.value = False
        in6.value = False
        in7.value = False
        in8.value = False
        time.sleep(5)
        while reading < selected_dose_water:
            temp = temp_prob.temperature
            if temp < 95:
                servo_1.angle = 0
            else:
                servo_1.angle = 90
            reading = round(hx.read(5),1)
            in5.value = True
            in6.value = False
            in7.value = True
            in8.value = False
            lcd.set_cursor_pos(1,0)
            lcd.print(str(reading)+ " g Water")
        in5.value = False
        in6.value = False
        in7.value = False
        in8.value = False
